﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using Word = Microsoft.Office.Interop.Word;

// Add a reference to the Word library.
// I used: Microsoft.Office.Interop.Word 12.0.0.0

namespace howto_convert_doc_to_docx
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Start in the executable directory.
        private void Form1_Load(object sender, EventArgs e)
        {
            txtDirectory.Text = Application.StartupPath;
        }

        // Let the user browse for a folder.
        private void btnBrowseForDirectory_Click(object sender, EventArgs e)
        {
            fbdSourceDirectory.SelectedPath = txtDirectory.Text;
            if (fbdSourceDirectory.ShowDialog() == DialogResult.OK)
            {
                txtDirectory.Text = fbdSourceDirectory.SelectedPath;
            }
        }

        // Convert the files in the directory.
        private void btnConvert_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;

            // Open the Word server.
            Word._Application word_app = new Word.ApplicationClass();

            // Make a couple of objects used inside and outside of the loop.
            object missing = System.Reflection.Missing.Value;
            object save_changes = false;

            // Loop through the files.
            int num_converted = 0;
            lstFiles.Items.Clear();
            DirectoryInfo dir_info = new DirectoryInfo(txtDirectory.Text);
            foreach (FileInfo file_info in dir_info.GetFiles("*.doc"))
            {
                // Skip .docx files.
                if (file_info.Extension.ToLower() == ".docx") continue;

                // Get the converted file's name.
                int name_length = file_info.FullName.Length - file_info.Extension.Length;
                string new_filename = file_info.FullName.Substring(0, name_length) + ".docx";

                // See if this file has already been converted.
                if (File.Exists(new_filename))
                {
                    lstFiles.Items.Add("Skipped " + file_info.Name);
                }
                else
                {
                    lstFiles.Items.Add("Converted " + file_info.Name);
                    num_converted++;

                    // Open the file.
                    object filename = file_info.FullName;
                    object confirm_conversions = false;
                    object read_only = true;
                    object add_to_recent_files = false;
                    object format = 0;
                    Word._Document word_doc =
                        word_app.Documents.Open(ref filename, ref confirm_conversions,
                            ref read_only, ref add_to_recent_files,
                            ref missing, ref missing, ref missing, ref missing,
                            ref missing, ref format, ref missing, ref missing,
                            ref missing, ref missing, ref missing, ref missing);

                    // Save as a .docx file.
                    filename = new_filename;
                    object file_format = Word.WdSaveFormat.wdFormatDocumentDefault;
                    word_doc.SaveAs(ref filename, ref file_format, ref missing, ref missing,
                        ref missing, ref missing, ref missing, ref missing, ref missing,
                        ref missing, ref missing, ref missing, ref missing, ref missing,
                        ref missing, ref missing);

                    // Close the document without prompting.
                    word_doc.Close(ref save_changes, ref missing, ref missing);
                }
            }

            // Close the word application.
            word_app.Quit(ref save_changes, ref missing, ref missing);

            int num_skipped = lstFiles.Items.Count - num_converted;
            MessageBox.Show("Converted " + num_converted.ToString() + " files.\n" +
                "Skipped " + num_skipped.ToString() + " files.",
                "Done", MessageBoxButtons.OK, MessageBoxIcon.Information);

            Cursor = Cursors.Default;
        }
    }
}
